# guppy

**DOI:** [10.5281/zenodo.8091508](https://doi.org/10.5281/zenodo.8091508)

## Available Versions
- **Version 6.4.2**
  - [Download](https://zenodo.org/record/8091509/files/guppy_6.4.2.img)
  - **MD5:** `9ad617716a0fdb7c5902662aaf433bc7`
  - **DOI:** [10.5281/zenodo.8091509](https://doi.org/10.5281/zenodo.8091509)
  - **Size:** 1201.66 MB
  - **Binaries:** 0 available

## Binaries (4 total)

```guppy_barcoder guppy_basecaller_duplex guppy_aligner guppy_basecaller```
